## toms. unix timestamp converter

toms is a command line tool that allows
 to convert unix epoch millis to iso date. And back


```
toms 1500000000000
2017-07-14T02:40:00+00:00
```

```
toms 2017-07-14T02:40
1500000000000
```

## install

```pip install toms```